import { FoundationTheme } from '../types/foundationTheme';

const LoraFont = '\'Lora\', serif';
const InterFont = '\'Inter\', sans-serif';

const typographyVariants = {
    h1: {
        fontFamily: LoraFont,
        fontSize: 42,
        lineHeight: 48,
        letterSpacingPercentage: 0,
        paragraphSpacing: 0,
    },
    h2: {
        fontFamily: LoraFont,
        fontSize: 36,
        lineHeight: 42,
        letterSpacingPercentage: 0,
        paragraphSpacing: 0,
    },
    h3: {
        fontFamily: LoraFont,
        fontSize: 32,
        lineHeight: 38,
        letterSpacingPercentage: 0,
        paragraphSpacing: 0,
    },
    h4: {
        fontFamily: LoraFont,
        fontSize: 26,
        lineHeight: 34,
        letterSpacingPercentage: 0,
        paragraphSpacing: 0,
    },
    h5: {
        fontFamily: LoraFont,
        fontSize: 22,
        lineHeight: 28,
        letterSpacingPercentage: 0,
        fontWeight: 700,
        paragraphSpacing: 0,
    },
    h6: {
        fontFamily: LoraFont,
        fontSize: 18,
        lineHeight: 24,
        letterSpacingPercentage: 0,
        fontWeight: 600,
        paragraphSpacing: 0,
    },
    'title-l': {
        fontFamily: InterFont,
        fontSize: 22,
        lineHeight: 28,
        letterSpacingPercentage: 2,
        fontWeight: 700,
        paragraphSpacing: 0,
    },
    'title-m': {
        fontFamily: InterFont,
        fontSize: 16,
        lineHeight: 20,
        letterSpacingPercentage: 4,
        fontWeight: 700,
        paragraphSpacing: 0,
    },
    'title-s': {
        fontFamily: InterFont,
        fontSize: 12,
        lineHeight: 16,
        letterSpacingPercentage: 4,
        fontWeight: 700,
        paragraphSpacing: 0,
    },
    'label-l': {
        fontFamily: InterFont,
        fontSize: 20,
        lineHeight: 26,
        letterSpacingPercentage: 0,
        fontWeight: 600,
        paragraphSpacing: 8,
    },
    'label-m': {
        fontFamily: InterFont,
        fontSize: 16,
        lineHeight: 22,
        letterSpacingPercentage: 0,
        fontWeight: 600,
        paragraphSpacing: 8,
    },
    'label-s': {
        fontFamily: InterFont,
        fontSize: 14,
        lineHeight: 20,
        letterSpacingPercentage: 0,
        fontWeight: 700,
        paragraphSpacing: 6,
    },
    'body-xl': {
        fontFamily: InterFont,
        fontSize: 18,
        lineHeight: 22,
        letterSpacingPercentage: 0,
        paragraphSpacing: 22,
    },
    'body-l': {
        fontFamily: InterFont,
        fontSize: 16,
        lineHeight: 22,
        letterSpacingPercentage: 0,
        paragraphSpacing: 20,
    },
    'body-m': {
        fontFamily: InterFont,
        fontSize: 14,
        lineHeight: 20,
        letterSpacingPercentage: 0,
        paragraphSpacing: 18,
    },
    'body-s': {
        fontFamily: InterFont,
        fontSize: 12,
        lineHeight: 16,
        letterSpacingPercentage: 1,
        paragraphSpacing: 16,
    },
    'body-xs': {
        fontFamily: InterFont,
        fontSize: 10,
        lineHeight: 14,
        letterSpacingPercentage: 2,
        paragraphSpacing: 14,
    },
    CTA: {
        fontFamily: InterFont,
        fontSize: 10.5,
        lineHeight: 20,
        letterSpacingPercentage: 1,
        paragraphSpacing: 0,
    },
};

const fonts: FoundationTheme.Theme['fonts'] = {
    'en-US': {
        defaultFont: InterFont,
        fontsToLoad: [
            {
                type: 'GoogleFont',
                fontName: 'Inter',
                fontStyle: [400, 600, 700],
            },
            {
                type: 'GoogleFont',
                fontName: 'Lora',
                fontStyle: [
                    [400, 0],
                    [600, 0],
                    [700, 1],
                ],
            },
        ],
        section: {
            body: InterFont,
            buttons: InterFont,
            captions: InterFont,
            headings: LoraFont,
            labels: InterFont,
            overlines: InterFont,
            subtitles: InterFont,
            title: InterFont,
        },
        typographyVariants,
    },
};

export default fonts;
